Towards an Integrated Multi-Physics Component \& Circuit Solver
===============================================================

It is important to understand the limitations of multi-physical solvers in order to know exactly how inaccurate our results are, and what we are really simulating.

.. include:: photonic.rst
.. include:: mixed_signal_electronic_photonic.rst
